@@ -143,6 +143,21 @@ describe('analyze', () => {
     })
     expect(diagnostics3).toEqual([])
   })
+
+  it('ensures tree-sitter does not crash', async () => {
+    // newer version of tree-sitter will crash on this file and never respond
+    // to new queries.
+    const analyzer = await getAnalyzer({ runBackgroundAnalysis: false })
+
+    // Parse the file
+    analyzer.analyze({
+      uri: FIXTURE_URI.CRASH,
+      document: FIXTURE_DOCUMENT.CRASH,
+    })
+
+    const result = analyzer.findAllSourcedUris({ uri: FIXTURE_URI.CRASH })
+    expect(result).toEqual(new Set([]))
+  })
 })
 
 describe('findDeclarationLocations', () => {
