@@ -16,7 +16,7 @@ import { CompletionItemDataType } from '../types'
 import { Logger } from '../util/logger'
 
 // Skip ShellCheck throttle delay in test cases
-jest.spyOn(global, 'setTimeout').mockImplementation((fn) => {
+jest.spyOn(global, 'setTimeout').mockImplementation((fn: any) => {
   fn()
   return 0 as any
 })
@@ -327,7 +327,19 @@ describe('server', () => {
             },
             kind: expect.any(Number),
             label: '--line-buffered',
-            insertText: 'buffered',
+            textEdit: {
+              newText: 'buffered',
+              range: {
+                start: {
+                  character: 12,
+                  line: 2,
+                },
+                end: {
+                  character: 12,
+                  line: 2,
+                },
+              },
+            },
           },
         ]),
       )
@@ -1055,16 +1067,16 @@ describe('server', () => {
     })
 
     it('responds with documentation even if parsing fails', async () => {
-      const result = await getHoverResult(FIXTURE_URI.MISSING_NODE2, {
-        // sleep
-        line: 12,
-        character: 4,
+      const result = await getHoverResult(FIXTURE_URI.MISSING_NODE, {
+        // echo
+        line: 11,
+        character: 2,
       })
 
       expect(result).toEqual({
         contents: {
           kind: 'markdown',
-          value: expect.stringContaining('sleep'),
+          value: expect.stringContaining('echo'),
         },
       })
     })
